Side classes
============

.. autosummary::

    nngt.GroupProperty
    nngt.NeuralGroup
    nngt.NeuralPop


Details
-------

.. currentmodule:: nngt

.. autoclass:: GroupProperty

.. autoclass:: NeuralGroup

.. autoclass:: NeuralPop
